/*
 * Copyright (c) 2011 Yan Pujante
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */

package org.linkedin.glu.orchestration.engine.delta;

import java.util.Collection;

/**
 * @author yan@pongasoft.com
 */
public class MultipleDeltaStatusInfo implements DeltaStatusInfo
{
  private final Collection<String> _values;

  /**
   * Constructor
   */
  public MultipleDeltaStatusInfo(Collection<String> values)
  {
    _values = values;
  }

  public Collection<String> getValues()
  {
    return _values;
  }

  @Override
  public Object toExternalRepresentation()
  {
    return getValues();
  }

  @Override
  public String toString()
  {
    return _values.toString();
  }

  public static DeltaStatusInfo create(Collection<String> values)
  {
    if(values == null)
      return null;

    if(values.size() == 1)
      return new SingleDeltaStatusInfo(values.iterator().next());
    else
      return new MultipleDeltaStatusInfo(values);
  }
}
